import { ipcMain, app } from 'electron'
import { MaProduct, MaRelease } from 'solar-js-sdk'
import { join } from 'path'
import * as fs from 'fs'

export interface AppLibrary {
  apps: LocalAppRecord[]
}

export let library: AppLibrary

function readLocalLibrary(): AppLibrary {
  const basePath = app.getPath('userData')
  const libraryPath = join(basePath, 'apps_library.json')
  console.log(`[Library] Loading library from ${libraryPath}`)
  if (fs.existsSync(libraryPath)) {
    const data = fs.readFileSync(libraryPath, 'utf-8')
    library = JSON.parse(data)
  } else {
    library = { apps: [] }
    saveLocalLibrary()
  }
  return library
}

function saveLocalLibrary() {
  const basePath = app.getPath('userData')
  const libraryPath = join(basePath, 'apps_library.json')
  fs.writeFileSync(libraryPath, JSON.stringify(library), 'utf-8')
}

export interface LocalAppRecord {
  id: string
  product: MaProduct
  release: MaRelease
  basePath: string
}

export function initLibrary(): void {
  readLocalLibrary()
  ipcMain.handle('get-app-library', () => getAppLibrary())
}

export function getAppLibrary(): LocalAppRecord[] {
  return library.apps
}

export function setAppRecord(record: LocalAppRecord) {
  let current = getAppLibrary()
  let hit = false

  current = current.map((rec) => {
    if (rec.id === record.id) hit = true
    return rec.id === record.id ? record : rec
  })

  if (!hit) {
    current.push(record)
  }

  library.apps = current
  saveLocalLibrary()
}
