import { ipcMain, WebContents } from 'electron'
import { MaProduct, MaRelease } from 'solar-js-sdk'

export interface InstallTask {
  id?: string
  product: MaProduct
  release: MaRelease
  basePath: string
  progress?: InstallProgress
  emitter?: WebContents
}

export enum InstallProgressPeriod {
  Initializing = 0,
  Downloading = 1,
  Extracting = 2,
  Installing = 3,
  Indexing = 4,
  Completed = 5,
}

export interface InstallProgress {
  value: number | null
  period: number
  details?: string | null
  error: string | null
  done: boolean
}

export const installTasks: Record<string, InstallTask> = {}

export function initTasks() {
  ipcMain.handle('get-install-tasks', () => JSON.stringify(Object.values(installTasks)))
}

export function updateInstallTask(task: InstallTask): void {
  if (!task.emitter) return
  if (task.id) installTasks[task.id] = task
  console.log(
    `[InstallTask] Task #${task.id} updated, progress: ${task.progress?.value}, period: ${task.progress?.period}, error: ${task.progress?.error}`,
  )
  task.emitter.send('update:install-task', JSON.stringify(task))
}
