import {
  AppBar,
  Toolbar,
  IconButton,
  Typography,
  Drawer,
  List,
  ListItem,
  ListItemButton,
  ListItemIcon,
  ListItemText,
} from '@mui/material'
import { useState } from 'react'

import GamepadIcon from '@mui/icons-material/Gamepad'
import ExploreIcon from '@mui/icons-material/Explore'
import AppsIcon from '@mui/icons-material/Apps'
import TaskIcon from '@mui/icons-material/Task'
import { useNavigate } from 'react-router'

export interface NavLink {
  title: string
  icon?: JSX.Element
  href: string
}

export function MaAppBar(): JSX.Element {
  const navigate = useNavigate()

  const [open, setOpen] = useState(false)

  const functionLinks: NavLink[] = [
    {
      title: 'Explore',
      icon: <ExploreIcon />,
      href: '/',
    },
    {
      title: 'Library',
      icon: <AppsIcon />,
      href: '/library',
    },
    {
      title: 'Tasks',
      icon: <TaskIcon />,
      href: '/tasks',
    },
  ]

  return (
    <>
      <Drawer open={open} onClose={() => setOpen(false)} sx={{ width: '320px' }}>
        <List sx={{ width: '320px' }}>
          {functionLinks.map((l) => (
            <ListItem disablePadding>
              <ListItemButton selected={window.location.pathname == l.href} onClick={() => navigate(l.href)}>
                <ListItemIcon>{l.icon}</ListItemIcon>
                <ListItemText primary={l.title} />
              </ListItemButton>
            </ListItem>
          ))}
        </List>
      </Drawer>

      <AppBar position="sticky">
        <Toolbar>
          <IconButton
            size="large"
            edge="start"
            color="inherit"
            aria-label="menu"
            sx={{ mr: 2 }}
            onClick={() => setOpen(true)}
          >
            <GamepadIcon />
          </IconButton>
          <Typography variant="h6" component="div" sx={{ flexGrow: 1 }}>
            Matrix
          </Typography>
        </Toolbar>
      </AppBar>
    </>
  )
}
