import { Box, Card, CardContent, Container, LinearProgress, Typography } from '@mui/material'
import { useEffect, useState } from 'react'
import { InstallTask } from '@main/tasks'

export default function Tasks(): JSX.Element {
  const [tasks, setTasks] = useState<InstallTask[]>([])

  function initListeners() {
    window.electron.ipcRenderer.on('update:install-task', (_, raw: string) => {
      const task = JSON.parse(raw)
      setTasks((tasks) => tasks.map((t) => (t.id === task.id ? task : t)))
    })
  }

  async function fetchTasks() {
    window.electron.ipcRenderer.invoke('get-install-tasks').then((res) => setTasks(JSON.parse(res)))
  }

  useEffect(() => {
    initListeners()
    fetchTasks()
  }, [])

  const periodLabels = ['Initializing', 'Downloading', 'Extracting', 'Installing', 'Indexing', 'Completed']

  return (
    <Container sx={{ py: 4 }}>
      <Typography variant="h5" component="h1">
        Tasks
      </Typography>

      <Box sx={{ mt: 3, display: 'flex', flexDirection: 'column', gap: 2 }}>
        {tasks.map((t) => (
          <Card variant="outlined" key={t.id}>
            <CardContent>
              <Typography variant="h6" component="h2" lineHeight={1.2}>
                {t.product.name}
              </Typography>
              <Typography variant="subtitle1" component="p" gutterBottom>
                {t.release.meta.title} {t.release.version}
              </Typography>

              <Typography variant="body1" component="p">
                {periodLabels[t.progress?.period ?? 0]} · Period {(t.progress?.period ?? 0) + 1}/6
              </Typography>
              {t.progress?.details && (
                <Typography variant="body2" component="p" fontFamily="monospace" fontSize={13}>
                  {t.progress.details}
                </Typography>
              )}

              <Box sx={{ mt: 2 }}>
                {t.progress?.value ? (
                  <LinearProgress
                    variant="determinate"
                    color={t.progress?.done ? 'success' : 'primary'}
                    value={t.progress.value * 100}
                    sx={{ borderRadius: 4 }}
                  />
                ) : (
                  <LinearProgress variant="indeterminate" sx={{ borderRadius: 4 }} />
                )}
              </Box>
            </CardContent>
          </Card>
        ))}
      </Box>
    </Container>
  )
}
